/* ------------------------------------------------------------ */
/*
HTTrack Website Copier, Offline Browser for Windows and Unix
Copyright (C) Xavier Roche and other contributors

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


Important notes:

- We hereby ask people using this source NOT to use it in purpose of grabbing
emails addresses, or collecting any other private information on persons.
This would disgrace our work, and spoil the many hours we spent on it.


This project has been developed by Xavier Roche and other contributors
(see the greetings and readme files)


Please visit our Website: http://www.httrack.com
*/

/* ------------------------------------------------------------ */
/* File: httracklib.h:                                          */
/* library definitions                                          */
/* ------------------------------------------------------------ */

#ifdef _cplusplus
extern "C" {
#endif

/*
 * Name:           HTTrackLib_main
 * Description:    Main HTTrack function
 * Parameters:     argc (number of arguments)
 *                 argv (arguments)
 * Returns:        Error status
*/
int HTTrackLib_main(int argc, char **argv);


/* CALLBACK FUNCTIONS */

/*
 * Name:           HTTrackLib_Init
 * Description:    Called during HTTrack initialization
 * Parameters:     None
 * Should return:  Nothing
*/
void HTTrackLib_Init();


/*
 * Name:           HTTrackLib_Close
 * Description:    Called during HTTrack termination
 * Parameters:     None
 * Should return:  Nothing
*/
void HTTrackLib_Close();


/*
 * Name:           HTTrackLib_Start
 * Description:    Called before HTTrack starts the mirror
 * Parameters:     None
 * Should return:  1 if no error has been detected
*/
int HTTrackLib_Start();

/*
 * Name:           HTTrackLib_End
 * Description:    Called after HTTrack ends the mirror
 * Parameters:     None
 * Should return:  1 if no error has been detected
*/
int HTTrackLib_End(); 


/*
 * Name:           HTTrackLib_TestLink
 * Description:    Test if a link has to be caught
 * Parameters:     host_name (host name, www.foo.com)
 *                 filename (filename, /index.html)
 *                 current_status
 *                   0: link should be accepted
 *                   1: link should be refused
 *                  -1: the engine has no opinion (by default, the link will be refused)
 * Should return:  new status
 *                   0: link will be accepted
 *                   1: link will be refused
 *                  -1: we do not have any opinion (by default, current status will be kept)
*/
int HTTrackLib_TestLink(char* host_name,char* filename,int current_status);


/*
 * Name:           HTTrackLib_TestParse
 * Description:    Test if an HTML file has to be parsed (after download)
 * Parameters:     host_name (host name, www.foo.com)
 *                 filename (filename, /index.html)
 *                 buffer_html (address of the HTML buffer)
 *                 buffer_html_size (size of this buffer in bytes)
 * Should return:  response
 *                   0: do not parse this file
 *                   1: parse this file (default behaviour)
*/
int HTTrackLib_TestParse(char* host_name,char* filename,char* buffer_html,int buffer_html_size);


#ifdef _cplusplus
}
#endif
